SystemOrganization addCategory: #'Seaside-Tests-UTF8'!

TestCase subclass: #WAUtf8FileTest
	instanceVariableNames: 'file'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-UTF8'!

!WAUtf8FileTest methodsFor: 'private' stamp: 'lr 7/25/2011 20:14'!
asString: aCollectionOfIntegers
	^ String streamContents: [ :stream |
		aCollectionOfIntegers do: [ :each |
			stream nextPut: (Character codePoint: each) ] ]! !

!WAUtf8FileTest methodsFor: 'private' stamp: 'pmm 11/15/2009 10:47'!
brokenUnicodeString
	^ self asString: #(83 195 169 195 164 115 195 174 100 195 169)! !

!WAUtf8FileTest methodsFor: 'running' stamp: 'pmm 11/14/2009 22:13'!
setUp
	file := WAFile new! !

!WAUtf8FileTest methodsFor: 'tests' stamp: 'pmm 11/15/2009 10:47'!
testContents
	file contents: #(83 195 169 195 164 115 195 174 100 195 169) asByteArray.
	self assert: file rawContents = #(83 195 169 195 164 115 195 174 100 195 169) asByteArray.
	self assert: file contents = self brokenUnicodeString.
	self assert: (file contentsDecodedUsing: 'UTF-8') = self unicodeString! !

!WAUtf8FileTest methodsFor: 'tests' stamp: 'pmm 11/15/2009 10:44'!
testContentsDecoded
	file contents:  #(83 195 169 195 164 115 195 174 100 195 169) asByteArray.
	self should: [ file contentsDecoded ] raise: WAIllegalStateException.
	file contentType: 'text/plain'.
	self should: [ file contentsDecoded ] raise: WAIllegalStateException.
	file contentType: 'text/plain; charset=utf-8' seasideMimeType.
	self assert: file contentsDecoded = self unicodeString
	! !

!WAUtf8FileTest methodsFor: 'private' stamp: 'pmm 11/15/2009 10:43'!
unicodeString
	^ self asString: #(83 233 228 115 238 100 233)! !

WAContextTest subclass: #WAUtf8ResponseTest
	instanceVariableNames: 'response'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-UTF8'!

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'lr 7/25/2011 20:14'!
asString: aCollectionOfIntegers
	^ String streamContents: [ :stream |
		aCollectionOfIntegers do: [ :each |
			stream nextPut: (Character codePoint: each) ] ]! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'pmm 7/5/2009 19:57'!
assertLines: anArray
	self assert: self lines = anArray! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'pmm 7/5/2009 19:57'!
contents
	| stream |
	stream := WriteStream on: String new.
	self response writeOn: stream.
	^ stream contents! !

!WAUtf8ResponseTest methodsFor: 'configuration' stamp: 'jf 9/30/2009 00:27'!
createCodec
	^ GRCodec forEncoding: 'utf-8'! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'jf 9/30/2009 01:06'!
lines
	"Answer the response as an array of lines, to be used within the tests."
	| result stream |
	result := OrderedCollection new.
	stream := self contents readStream.
	[ stream atEnd ] whileFalse: 
		[ result add: (stream greaseUpToAll: (String 
					with: Character cr
					with: Character lf)) ].
	^ result asArray! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'pmm 7/5/2009 19:57'!
response
	^ response ifNil: [ response := WABufferedResponse new ]! !

!WAUtf8ResponseTest methodsFor: 'tests' stamp: 'pmm 7/5/2009 20:04'!
testRedirectTo
	| url |
	url :=  WAUrl absolute: 'http://www.seaside.st/'.
	url addToPath: self unicodeString.
	self response redirectTo: url.
	self assertLines:  #('HTTP/1.1 302 Found'
		'Location: http://www.seaside.st/%C2%A5%C2%A3%E2%82%AC%24%C2%A2%E2%82%A1%E2%82%A2%E2%82%A3%E2%82%A4%E2%82%A5%E2%82%A6%E2%82%A7%E2%82%A8%E2%82%A9%E2%82%AA%E2%82%AB%E2%82%AD%E2%82%AE%E2%82%AF'
		'Content-Length: 0' '')! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'pmm 7/5/2009 19:53'!
unicodeString
	^ self asString: #(165 163 8364 36 162 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8365 8366 8367)! !

WAContextTest subclass: #WAUtf8UrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-UTF8'!

!WAUtf8UrlTest methodsFor: 'private' stamp: 'lr 7/25/2011 20:14'!
asString: aCollectionOfIntegers
	^ String streamContents: [ :stream |
		aCollectionOfIntegers do: [ :each |
			stream nextPut: (Character codePoint: each) ] ]! !

!WAUtf8UrlTest methodsFor: 'configuration' stamp: 'jf 9/30/2009 00:27'!
createCodec
	^ GRCodec forEncoding: 'utf-8'! !

!WAUtf8UrlTest methodsFor: 'tests' stamp: 'pmm 7/5/2009 20:06'!
testPrintString
	| url |
	url :=  WAUrl absolute: 'http://www.seaside.st/'.
	url addToPath: self unicodeString.
	self assert: url printString = 'http://www.seaside.st/%C2%A5%C2%A3%E2%82%AC%24%C2%A2%E2%82%A1%E2%82%A2%E2%82%A3%E2%82%A4%E2%82%A5%E2%82%A6%E2%82%A7%E2%82%A8%E2%82%A9%E2%82%AA%E2%82%AB%E2%82%AD%E2%82%AE%E2%82%AF'! !

!WAUtf8UrlTest methodsFor: 'private' stamp: 'pmm 7/5/2009 20:05'!
unicodeString
	^ self asString: #(165 163 8364 36 162 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8365 8366 8367)! !

!GRPackage class methodsFor: '*seaside-tests-utf8' stamp: 'lr 2/17/2010 15:14'!
seasideTestsUtf8
	^ self new
		name: 'Seaside-Tests-UTF8';
		description: 'Unit tests for UTF8 support.';
		addDependency: 'Seaside-Tests-Core';
		url: #seasideUrl;
		yourself! !
